@@ -15,6 +15,7 @@ from controlSBML.make_roadrunner import makeRoadrunner
 import controlSBML as ctl
 from controlSBML import util
 from controlSBML import msgs
+import controlSBML.siso_transfer_function_builder as stb
 
 import control
 import numpy as np
@@ -156,7 +157,7 @@ class ControlBase(object):
               self.state_names)) > 0
         if self.is_reduced and is_state_input:
             raise ValueError("Cannot handle input states for is_reduced=True")
-        # Initializations 
+        # Initializations
         state_names = self.state_names
         # Delete states that are inputs
         # TODO: Delete since no longer deleting input state
@@ -294,7 +295,7 @@ class ControlBase(object):
         Parameters
         ----------
         time: float
-        
+
         Returns
         -------
         pd.DataFrame
@@ -404,7 +405,7 @@ class ControlBase(object):
         object/dict
         """
         if names is None:
-            names = [k for k in self.roadrunner.keys() if not ")" in k] 
+            names = [k for k in self.roadrunner.keys() if not ")" in k]
         if isinstance(names, str):
             return self.roadrunner[names]
         return {n: self.roadrunner[n] for n in names}
@@ -607,7 +608,7 @@ class ControlBase(object):
         ss = control.StateSpace(A_mat, B_mat, C_mat, D_mat)
         return ss
 
-    def makeNonlinearIOSystem(self, name, effector_dct=None):
+    def makeNonlinearIOSystem(self, name):
         """
         Creates an object that can be used in connections with the
         control package.
@@ -615,15 +616,12 @@ class ControlBase(object):
         Parameters
         ----------
         name: str (name of the system)
-        effector_dct: dict (maps reaction inputs to roadrunner muteables)
-            key: str (input name)
-            value: str (name of roadrunner muteable)
 
         Returns
         -------
         controlSBML.NonelinearIOSystem
         """
-        return ctl.NonlinearIOSystem(name, self, effector_dct=effector_dct)
+        return ctl.NonlinearIOSystem(name, self)
 
     @staticmethod
     def reduceTransferFunction(tf, atol=ATOL):
@@ -633,7 +631,7 @@ class ControlBase(object):
         Parameters
         ----------
         tf: control.TransferFunction
-        
+
         Returns
         -------
         tf: control.TransferFunction
@@ -658,17 +656,48 @@ class ControlBase(object):
         new_tf = control.TransferFunction(new_numerator, new_denominator)
         return new_tf
 
+    def makeSISOTransferFunctionBuilder(self, system_name="sys",
+          input_name=None, output_name=None):
+        """
+        Creates a SISOTransferFunctionBuilder to construct a SISO transfer function.
+        The default input and output names are the first input and output names.
+
+        Parameters
+        ----------
+        system_name: str
+        input_name: str
+        output_name: str
+
+        Returns
+        -------
+        SISOTransferFunctionBuilder
+        """
+        def getName(specified_name, names):
+            if specified_name is None:
+                if len(names) < 1:
+                    raise ValueError("Must specify at least one name")
+                name = names[0]
+            else:
+                name = specified_name
+            return name
+        #
+        input_name = getName(input_name, self.input_names)
+        output_name = getName(output_name, self.output_names)
+        sys = self.makeNonlinearIOSystem(system_name)
+        return stb.SISOTransferFunctionBuilder(sys, input_name=input_name,
+              output_name=output_name)
+
     def makeTransferFunction(self, time=None, atol=ATOL):
         """
         Creates a transfer function for the system. Verifies that there
         is a single input and a single output. Reduces the order of the
         transfer function as needed.
-        
+
         Parameters
         ----------
         time: float (time at which Jacobian is obtained)
         atol: absolute tolerance for comparison
-        
+
         Returns
         -------
         control.TransferFunction
@@ -697,7 +726,7 @@ class ControlBase(object):
         ----------
         time: float
             Time at which this is calculated
-        
+
         Returns
         -------
         pd.DataFrame
